# mockserial

[![codecov](https://codecov.io/github/christianhbye/mockserial/graph/badge.svg?token=3RyhEqZz3O)](https://codecov.io/github/christianhbye/mockserial)

MockSerial provides a mock instance of the Serial class in Python, implemented e.g. by [pySerial](https://github.com/pyserial/pyserial/). This can be used to test code that requires a serial connection between devices.
